@@ -19,16 +19,14 @@ import os
 import re
 import subprocess
 
-__version__ = '21.0.2'
-__copyright__ = (
-    'Copyright 2021, The NiPreps Developers'
-)
+__version__ = '22.1.1'
+__copyright__ = 'Copyright 2022, The NiPreps Developers'
 __bugreports__ = 'https://github.com/nipreps/nibabies/issues'
 
 MISSING = """
 Image '{}' is missing
 Would you like to download? [Y/n] """
-PKG_PATH = "/usr/local/miniconda/lib/python3.8/site-packages"
+PKG_PATH = "/opt/conda/lib/python3.9/site-packages"
 TF_TEMPLATES = (
     "MNI152Lin",
     "MNI152NLin2009cAsym",
@@ -120,9 +118,7 @@ class ContainerManager(object):
         dst : absolute container path
         read_only : disable writing to bound path
         """
-        self.mounts.append(
-            "{0}:{1}{2}".format(src, dst, ":ro" if read_only else "")
-        )
+        self.mounts.append("{0}:{1}{2}".format(src, dst, ":ro" if read_only else ""))
 
     def check_install(self):
         """Verify that the service is installed and the user has permission to
@@ -153,9 +149,7 @@ class ContainerManager(object):
     def check_image(self, image):
         """Check whether image is present on local system"""
         if self.service == "docker":
-            ret = subprocess.run(
-                ["docker", "images", "-q", image], stdout=subprocess.PIPE
-            )
+            ret = subprocess.run(["docker", "images", "-q", image], stdout=subprocess.PIPE)
             return bool(ret.stdout)
         elif self.service == "singularity":
             # check if the image file exists
@@ -268,6 +262,9 @@ def merge_help(wrapper_help, target_help):
     expected_overlap = {
         "anat-derivatives",
         "bids-database-dir",
+        "bids-filter-file",
+        "derivatives",
+        "deriv-filter-file",
         "fs-license-file",
         "fs-subjects-dir",
         "config-file",
@@ -346,9 +343,7 @@ def get_parser():
         """Ensure a given path exists and it is a file."""
         path = os.path.abspath(path)
         if not os.path.isfile(path):
-            raise parser.error(
-                "Path should point to a file (or symlink of file): <%s>." % path
-            )
+            raise parser.error("Path should point to a file (or symlink of file): <%s>." % path)
         return path
 
     parser = argparse.ArgumentParser(
@@ -464,7 +459,26 @@ the spatial normalization."""
         "--segmentation-atlases-dir",
         metavar="PATH",
         type=os.path.abspath,
-        help="Directory containing prelabeled segmentations to use for JointLabelFusion."
+        help="Directory containing prelabeled segmentations to use for JointLabelFusion.",
+    )
+    g_wrap.add_argument(
+        "--derivatives",
+        nargs="+",
+        metavar="PATH",
+        type=os.path.abspath,
+        help="One or more directory containing pre-computed derivatives",
+    )
+    g_wrap.add_argument(
+        "--bids-filter-file",
+        metavar="PATH",
+        type=os.path.abspath,
+        help="Filter file",
+    )
+    g_wrap.add_argument(
+        "--deriv-filter-file",
+        metavar="PATH",
+        type=os.path.abspath,
+        help="Filter file",
     )
 
     # Developer patch/shell options
@@ -511,9 +525,7 @@ the spatial normalization."""
         help="Run container with a different network driver "
         '("none" to simulate no internet connection)',
     )
-    g_dev.add_argument(
-        "--no-tty", action="store_true", help="Run docker without TTY flag -it"
-    )
+    g_dev.add_argument("--no-tty", action="store_true", help="Run docker without TTY flag -it")
 
     return parser
 
@@ -530,44 +542,33 @@ def main():
         return
 
     # Set help if no directories set
-    if not all((opts.service, opts.bids_dir, opts.output_dir)):
+    if opts.help or not all((opts.service, opts.bids_dir, opts.output_dir)):
         parser.print_help()
-        return 1
+        return
 
     container = ContainerManager(opts.service, image=opts.image)
     check = container.check_install()
     if check < 1:
-        if opts.version:
-            print("nibabies wrapper {!s}".format(__version__))
-        if opts.help:
-            parser.print_help()
         if check == -1:
             print(
-                "nibabies: Could not find %s command... Is it installed?"
-                % opts.service
+                "nibabies: Could not find %s command... Is it installed?" % opts.service,
             )
         else:
             print(
-                "nibabies: Make sure you have permission to run '%s'" % opts.service
+                "nibabies: Make sure you have permission to run '%s'" % opts.service,
             )
         return 1
 
-    # For --help or --version, ask before downloading an image
     if not container.check_image(opts.image):
         resp = "Y"
-        if opts.version:
-            print("nibabies wrapper {!s}".format(__version__))
-        if opts.help:
-            parser.print_help()
-        if opts.version == "singularity":
-            print("Singularity images must already exist locally.")
+        if opts.service == "singularity":
+            print("Singularity image must already exist locally.")
+            return 1
+        try:
+            resp = input(MISSING.format(opts.image))
+        except KeyboardInterrupt:
+            print()
             return 1
-        if opts.version or opts.help:
-            try:
-                resp = input(MISSING.format(opts.image))
-            except KeyboardInterrupt:
-                print()
-                return 1
         if resp not in ("y", "Y", ""):
             return 0
         print("Downloading. This may take a while...")
@@ -580,10 +581,7 @@ def main():
             "Do you have permission to run docker?"
         )
         return 1
-    if (
-        not (opts.help or opts.version or "--reports-only" in unknown_args)
-        and mem_total < 8000
-    ):
+    if "--reports-only" not in unknown_args and mem_total < 8000:
         print(
             "Warning: <8GB of RAM is available within your environment.\n"
             "Some parts of nibabies may fail to complete."
@@ -602,11 +600,7 @@ def main():
 
     if opts.service == "docker":
         if not opts.no_tty:
-            if opts.help:
-                # TTY can corrupt stdout
-                container.add_cmd("-i")
-            else:
-                container.add_cmd("-it")
+            container.add_cmd("-it")
         if opts.user:
             container.add_cmd(("-u", opts.user))
         if opts.network:
@@ -650,6 +644,19 @@ def main():
     if opts.segmentation_atlases_dir:
         container.add_mount(opts.segmentation_atlases_dir, "/opt/segmentations")
         unknown_args.extend(["--segmentation-atlases-dir", "/opt/segmentations"])
+    if opts.bids_filter_file:
+        container.add_mount(opts.bids_filter_file, "/opt/bids_filters.json")
+        unknown_args.extend(["--bids-filter-file", "/opt/bids_filters.json"])
+    if opts.deriv_filter_file:
+        container.add_mount(opts.deriv_filter_file, "/opt/derivative_filters.json")
+        unknown_args.extend(["--deriv-filter-file", "/opt/derivative_filters.json"])
+    if opts.derivatives:
+        derivative_args = ["--derivatives"]
+        for derivative in opts.derivatives:
+            derivative_target = "/opt/derivatives/%s" % os.path.basename(derivative)
+            container.add_mount(derivative, derivative_target, read_only=False)
+            derivative_args.append(derivative_target)
+        unknown_args.extend(derivative_args)
 
     # Check that work_dir is not a child of bids_dir
     if opts.work_dir and opts.bids_dir:
@@ -683,9 +690,7 @@ def main():
             if space.split(":")[0] not in (TF_TEMPLATES + NONSTANDARD_REFERENCES):
                 tpl = os.path.basename(space)
                 if not tpl.startswith("tpl-"):
-                    raise RuntimeError(
-                        "Custom template %s requires a `tpl-` prefix" % tpl
-                    )
+                    raise RuntimeError("Custom template %s requires a `tpl-` prefix" % tpl)
                 target = "/home/fmriprep/.cache/templateflow/" + tpl
                 container.add_mount(os.path.abspath(space), target)
                 spaces.append(tpl[4:])
@@ -707,16 +712,16 @@ def main():
 
     # Override help and version to describe underlying program
     # Respects '-i' flag, so will retrieve information from any image
-    if opts.help:
-        container.add_cmd("-h")
-        targethelp = subprocess.check_output(container.command).decode()
-        print(merge_help(parser.format_help(), targethelp))
-        return 0
-    elif opts.version:
-        # Get version to be run and exit
-        container.add_cmd("--version")
-        ret = subprocess.run(container.command)
-        return ret.returncode
+    # if opts.help:
+    #     container.add_cmd("-h")
+    #     targethelp = subprocess.check_output(container.command).decode()
+    #     print(merge_help(parser.format_help(), targethelp))
+    #     return 0
+    # elif opts.version:
+    #     # Get version to be run and exit
+    #     container.add_cmd("--version")
+    #     ret = subprocess.run(container.command)
+    #     return ret.returncode
 
     if not opts.shell:
         container.add_cmd(main_args)
